<?php

class GoogleMap_Shortcode {

	static function init() {
		add_shortcode('map', array(__CLASS__, 'render_shortcode'));
		add_action('wp_footer', array(__CLASS__, 'enqueue_map_javascript'));		
		add_action('admin_menu', array(__CLASS__, 'add_google_map_admin_menu'));
	}
	
	static function add_google_map_admin_page() {
		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}
		
		if ( $_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['api_key']) ){
			$api_key = $_POST['api_key'];
			update_option( 'GOOGLE_MAP_API_KEY', $api_key );
		}
		// GET HTML
		?>
		<div class="google-map-options">
			<h1>Google Map Options</h1>
			<form name="options" method="POST" action="<?php echo $_SERVER['REQUEST_URI']; ?>">
				<label for="api_key">Google Map API Key<span class="required">(*)</span>: </label>
				<input type="text" name="api_key" value="<?php echo get_option( 'GOOGLE_MAP_API_KEY', '' ); ?>" size="70">
				<input class="button-primary" type="submit" name="save" />					
				<br/>
				<small>You can sign up for a API key <a href="https://developers.google.com/maps/signup" target="_blank">here</a></small>				
			</form>
			<br />
			<?php echo do_shortcode('[map]'); ?>
		</div>
		<?php
	}

	static function add_google_map_admin_menu() {  	
		add_options_page('Google Map Options', 'Google Map', 'manage_options', 'settings.php', array(__CLASS__, 'add_google_map_admin_page'));
		add_action( 'admin_print_scripts', array(__CLASS__, 'enqueue_map_javascript'));
	}  

	static function render_shortcode($atts) {
		$api_key = get_option( 'GOOGLE_MAP_API_KEY' );
		extract( shortcode_atts( array(
			'id' => 'map-canvas-1',
			'class' => '',
			'zoom' => '18',
			'coords' => '53.339381, -6.260405',
			'type' => 'roadmap',
			'width' => '480px',
			'height' => '480px'
		), $atts ) );
		
		$return = "";
		
		$map_type_id = "google.maps.MapTypeId.ROADMAP";
		
		switch ($type) {
			case "roadmap":
				$map_type_id = "google.maps.MapTypeId.ROADMAP";
				break;
			case "satellite":
				$map_type_id = "google.maps.MapTypeId.SATELLITE";
				break;
			case "hybrid":
				$map_type_id = "google.maps.MapTypeId.HYBRID";
				break;
			case "terrain":
				$map_type_id = "google.maps.MapTypeId.TERRAIN";
				break;
		}
		
		if($api_key) {
			$return = '<div id="'.$id.'" class="map-canvas '.$class.'" style="width:'.$width.';height:'.$height.';" ></div>';
			
			$return .= '<script type="text/javascript">';
			$return .= 'jQuery(document).on("ready", function(){ ';
			$return .= 'var options = { center: new google.maps.LatLng('.$coords.'),';
			$return .= 'zoom: ' . $zoom . ', mapTypeId: ' . $map_type_id . ' };';
			$return .= 'var map = new google.maps.Map(document.getElementById("'.$id.'"), options);';
			$return .= 'var marker = new google.maps.Marker({ position: new google.maps.LatLng('.$coords.'), map: map });';
			$return .= '});</script>';
			
		} else {
			$return = "<div><p>Please specify your Google Maps API key</p></div>";
		}
		
		return $return;		
	}
	
	static function enqueue_map_javascript() {
		$api_key = get_option( 'GOOGLE_MAP_API_KEY' );
		
		if ( ! $api_key )
			return;

		wp_enqueue_script( 'map-js', 
			"https://maps.googleapis.com/maps/api/js?key=" . $api_key . "&sensor=true",
			"jquery"
		);
	}
}

GoogleMap_Shortcode::init();
?>